@@ -1,29 +1,20 @@
-# ------------------------------------------------------------------------------
-# Copyright (c) 2005, Enthought, Inc.
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in /LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
-# ------------------------------------------------------------------------------
-
-from __future__ import absolute_import
 
 import unittest
 
-try:
-    import numpy
-except ImportError:
-    numpy_available = False
-else:
-    numpy_available = True
-
 from traits.api import Array, Bool, HasTraits
+from traits.testing.optional_dependencies import numpy, requires_numpy
 
 
-if numpy_available:
+if numpy is not None:
     # Use of `Array` requires NumPy to be installed.
 
     class Foo(HasTraits):
@@ -37,7 +28,7 @@ if numpy_available:
 class ArrayTestCase(unittest.TestCase):
     """ Test cases for delegated traits. """
 
-    @unittest.skipUnless(numpy_available, "numpy not available")
+    @requires_numpy
     def test_zero_to_one_element(self):
         """ Test that an event fires when an Array trait changes from zero to
         one element.
