@@ -1,19 +1,12 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   06/21/2002
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines the standard exceptions raised by the Traits package.
 """
@@ -22,14 +15,8 @@
 #  Imports:
 # -------------------------------------------------------------------------------
 
-from __future__ import absolute_import
-
-import sys
-
 from .trait_base import class_of
 
-from . import _py2to3
-
 # -------------------------------------------------------------------------------
 #  Utilities
 # -------------------------------------------------------------------------------
@@ -39,7 +26,7 @@ def repr_type(obj):
     """ Return a string representation of a value and its type for readable
     error messages.
     """
-    the_type = _py2to3.type_w_old_style(obj)
+    the_type = type(obj)
     msg = "%r %r" % (obj, the_type)
     return msg
 
@@ -89,7 +76,6 @@ class TraitError(Exception):
 
         # Note: self.args must be a tuple so be sure to leave the trailing
         # commas.
-        the_type = _py2to3.type_w_old_style(self.value)
         if obj is not None:
             self.args = (
                 (
@@ -140,12 +126,3 @@ class DelegationError(TraitError):
     def __init__(self, args):
         # .args must be a tuple.
         self.args = (args,)
-
-
-# -------------------------------------------------------------------------------
-#  Export the defined exceptions to the C-base traits module:
-# -------------------------------------------------------------------------------
-
-from . import ctraits
-
-ctraits._exceptions(TraitError, DelegationError)
